summaryrefslogtreecommitdiffstats
path: root/kig/misc/object_hierarchy.h
diff options
context:
space:
mode:
Diffstat (limited to 'kig/misc/object_hierarchy.h')
-rw-r--r--kig/misc/object_hierarchy.h10
1 files changed, 5 insertions, 5 deletions
diff --git a/kig/misc/object_hierarchy.h b/kig/misc/object_hierarchy.h
index 35e7cbef..5997015c 100644
--- a/kig/misc/object_hierarchy.h
+++ b/kig/misc/object_hierarchy.h
@@ -73,16 +73,16 @@ public:
std::vector<ObjectImp*> calc( const Args& a, const KigDocument& doc ) const;
/**
* saves the ObjectHierarchy data in tqchildren xml tags of \p tqparent ..
*/
- void serialize( TQDomElement& tqparent, TQDomDocument& doc ) const;
+ void serialize( TQDomElement& parent, TQDomDocument& doc ) const;
/**
* Deserialize the ObjectHierarchy data from the xml element \p tqparent ..
* Since this operation can fail for some reasons, we provide it as a
* static to return 0 in case of error.
*/
- static ObjectHierarchy* buildSafeObjectHierarchy( const TQDomElement& tqparent, TQString& error );
-// ObjectHierarchy( const TQDomElement& tqparent );
+ static ObjectHierarchy* buildSafeObjectHierarchy( const TQDomElement& parent, TQString& error );
+// ObjectHierarchy( const TQDomElement& parent );
/**
* build a set of objects that interdepend according to this
@@ -73,16 +73,16 @@ public:
std::vector<ObjectImp*> calc( const Args& a, const KigDocument& doc ) const;
/**
- * saves the ObjectHierarchy data in tqchildren xml tags of \p tqparent ..
+ * saves the ObjectHierarchy data in tqchildren xml tags of \p parent ..
*/
@@ -73,16 +73,16 @@ public:
/**
- * Deserialize the ObjectHierarchy data from the xml element \p tqparent ..
+ * Deserialize the ObjectHierarchy data from the xml element \p parent ..
* Since this operation can fail for some reasons, we provide it as a
* static to return 0 in case of error.